@@ -1,11 +1,9 @@
-context("test-Categorical")
-
 test_that("print.Categorical", {
   X <- Categorical(1:6)
   Y <- Categorical(LETTERS[1:3], p = c(0.1, 0.2, 0.7))
 
-  expect_output(print(X), regexp = "Categorical distribution")
-  expect_output(print(Y), regexp = "Categorical distribution")
+  expect_output(print(X), regexp = "Categorical")
+  expect_output(print(Y), regexp = "Categorical")
 })
 
 test_that("random.Categorical", {
