@@ -1,7 +1,5 @@
-context("test-LogNormal")
-
 test_that("print.LogNormal works", {
-  expect_output(print(LogNormal()), regexp = "LogNormal distribution")
+  expect_output(print(LogNormal()), regexp = "LogNormal")
 })
 
 test_that("likelihood.LogNormal and log_likelihood.LogNormal work correctly", {
@@ -23,7 +21,7 @@ test_that("random.LogNormal work correctly", {
   expect_length(random(cau[-1], 1), 0)
   expect_length(random(cau, 0), 0)
   expect_error(random(cau, -2))
- 
+
   # consistent with base R, using the `length` as number of samples to draw
   expect_length(random(cau, c(1, 2, 3)), 3)
   expect_length(random(cau, cbind(1, 2, 3)), 3)
@@ -109,6 +107,20 @@ test_that("vectorization of a LogNormal distribution work correctly", {
     )
   )
 
+  ## elementwise
+  expect_equal(
+    pdf(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(pdf(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+  expect_equal(
+    cdf(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(cdf(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+  expect_equal(
+    quantile(d, c(0.25, 0.75), elementwise = TRUE),
+    diag(quantile(d, c(0.25, 0.75), elementwise = FALSE))
+  )
+
   ## support
   expect_equal(
     support(d),
@@ -117,6 +129,8 @@ test_that("vectorization of a LogNormal distribution work correctly", {
       ncol = 2, dimnames = list(names(d), c("min", "max"))
     )
   )
+  expect_true(!any(is_discrete(d)))
+  expect_true(all(is_continuous(d)))
   expect_true(is.numeric(support(d1)))
   expect_true(is.numeric(support(d1, drop = FALSE)))
   expect_null(dim(support(d1)))
