@@ -1,7 +1,5 @@
-context("test-Multinomial")
-
 test_that("print.Multinomial works", {
-  expect_output(print(Multinomial(1, 0.5)), regexp = "Multinomial distribution")
+  expect_output(print(Multinomial(1, 0.5)), regexp = "Multinomial")
 })
 
 test_that("likelihood.Multinomial and log_likelihood.Multinomial work correctly", {
@@ -21,7 +19,7 @@ test_that("random.Multinomial work correctly", {
   # expect_length(random(m[-1], 1), 0)
   expect_length(random(m, 0), 0)
   expect_error(random(m, -2))
- 
+
   # consistent with base R, using the `length` as number of samples to draw
   # expect_length(random(m, c(1, 2, 3)), 3)
   # expect_length(random(m, cbind(1, 2, 3)), 3)
